@@ -17,10 +17,11 @@ from polity.static import (
     EQUITIES_PUBLIC_API_KEY,
     COMPANY_SCHEMA    
 )
+import matplotlib.pyplot as plt 
 
 class Client():
 
-    def __init__(self,api_key,dev=True):
+    def __init__(self,api_key,dev=False):
 
         def invert_dict(to_invert):
             return {v:k for k,v in to_invert.items()}
@@ -60,6 +61,12 @@ class Client():
         )
         return graphql
 
+    def _test(self):
+        for cik in self.ciks()[560:565]:
+            c = self.company(cik,df=True)
+            c['income'].T.plot(kind='bar',stacked=True)
+        plt.show()
+
     def _fetch_equities_messages(self):
         query = gql.gql(EQUITIES_MESSAGES_QUERY)
         return self.graphql.execute(query)['equitiesMessages']
